package adlpadmin::notifications;

use strict;

use Gtk2 '-init';
use Glib ':constants';
use Glib qw/TRUE FALSE/;

=encoding utf8

=head1 SYNOPSIS

 use adlpadmin::notifications;

 my $notifications = new adlpadmin::notifications($parent_window);
 
 # Wait until you have 15 minutes to leave your office
 $notifications->stop_warning("I'm leaving in 15 minutes");
 
 # Wait for 15 minutes
 $notifications->stop_fatal("Out of working hours");

=head1 DESCRIPTION

adlpadmin::notification helps you to create Gtk2 Error and Warning dialogs.

=head1 METHODS

=over 4

=item new

The constructor needs your Gtk2 parent window reference.

=cut

sub new {
	my ($class, $parent) = @_;
	
	my $self = {};
	
	$self->{'parent'} = $parent;
	
	bless($self, $class);
	
	return $self;
	}

=item stop_fatal

Throws fatal error message. When user clicks OK stop with exit code 1.

 $notifications->stop_fatal("Out of working hours");
 
=cut

sub stop_fatal {
	my ($class, $message) = @_;

	print "STOP FATAL: $message\n";
	
	my $dialog = Gtk2::MessageDialog->new($class->{'parent'},
		'destroy-with-parent',
		'error',
		'close',
		$message);

	# If OK pressed exit with error code 1
	$dialog->signal_connect (response => sub {
		my ($self, $response) = @_;
		$self->destroy;
		exit(1);
		});
	
	$dialog->show_all;
	$class->flush_gtk_events();
	}

=item give_warning

Throws warning message.

 $notifications->stop_warning("I'm leaving in 15 minutes");
 
=cut

sub give_warning {
	my ($class, $message) = @_;
	
	print "WARNING: $message\n";

	my $dialog = Gtk2::MessageDialog->new($class->{'parent'},
		'destroy-with-parent',
		'warning',
		'ok',
		$message);

	# If OK pressed exit with error code 1
	$dialog->signal_connect (response => sub {
		my ($self, $response) = @_;
		$self->destroy;
		});
	
	$dialog->show_all;
	$class->flush_gtk_events();
	}

=item flush_gtk_events

Flushes pending Gtk2 events. For internal use.

 $notifications->flush_gtk_events();
 
=cut

sub flush_gtk_events {
	# Flush all pending Gtk2 events
	my ($class) = @_;
	
	while (Gtk2->events_pending) {
		Gtk2->main_iteration;
		}
	}
	
=back

=cut

1;
	
__END__

=head1 AUTHOR

Matti Lattu (matti.lattu@helsinki.fi)

=head1 LICENSE AND COPYRIGHT

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself, either Perl version 5.10.1 or,
at your option, any later version of Perl 5 you may have available.

Copyright (C) 2013 University of Helsinki

